nbqol.devices
=============

.. automodule:: nbqol.devices

   
   .. rubric:: Functions

   .. autosummary::
   
      count_cuda_devices
      cuda_device_report
      cuda_visibles
      format_key
      get_nvidia_smi
      memory_to_gb
      normalize_device_ids
      safe_subprocess_call
      set_cuda_visibles
      torch_device_report
   
   .. rubric:: Classes

   .. autosummary::
   
      Any
   